from __future__ import print_function

from trakt_tools.core.authentication import authenticate
from trakt_tools.tasks import MergeHistoryDuplicatesTask

import click
import os


@click.command('history:duplicates:merge')
@click.option(
    '--token',
    default=None,
    help='Trakt.tv authentication token. (default: prompt)'
)
@click.option(
    '--backup-dir',
    default=None,
    help='Directory that backups should be stored in. (default: "./backups")'
)
@click.option(
    '--delta-max',
    default=10 * 60,
    help='Maximum delta between history records to consider as duplicate. (in seconds) (default: 600)'
)
@click.option(
    '--per-page',
    default=1000,
    help='Request page size. (default: 1000)'
)
@click.option(
    '--backup/--no-backup',
    default=None,
    help='Backup profile before applying any changes. (default: prompt)'
)
@click.option(
    '--review/--no-review',
    default=None,
    help='Review each action before applying them. (default: prompt)'
)
@click.pass_context
def history_duplicates_merge(ctx, token, backup_dir, delta_max, per_page, backup, review):
    """Merge duplicate history records"""

    if not token:
        success, token = authenticate()

        if not success:
            print('Authentication failed')
            exit(1)

        print()

    # Set default backup directory
    if not backup_dir:
        backup_dir = os.path.join(os.curdir, 'backups')

    # Ensure backup directory exists
    if not os.path.exists(backup_dir):
        os.makedirs(backup_dir)

    # Run task
    success = MergeHistoryDuplicatesTask(
        backup_dir=backup_dir,
        delta_max=delta_max,
        per_page=per_page,

        debug=ctx.parent.debug,
        rate_limit=ctx.parent.rate_limit
    ).run(
        token=token,
        backup=backup,
        review=review
    )

    if not success:
        exit(1)



from argparse import ArgumentParser
from subprocess import Popen
import os


DEPENDENCIES = [
    ('develop', [
        '-rrequirements_develop.txt',
        '-rtests/requirements.txt'
    ]),
    ('pip', [
        '-rrequirements.txt',
        '-rtests/requirements.txt'
    ]),
    ('travis', [
        '-rrequirements_vendor.txt',
        '-rtests/requirements.txt',

        '--editable=git+https://github.com/fuzeman/trakt.py.git@{BRANCH}#egg=trakt-py'
    ]),
    ('flake8', [
        'flake8'
    ]),
    ('py32', [
        'coverage==3.7.1',
        'pytest>=2.7.0, < 3.0.0',
        'requests>=2.4.0, < 2.11.0'
    ]),
]


if __name__ == '__main__':
    parser = ArgumentParser()
    parser.add_argument('env')

    args = parser.parse_args()

    # Retrieve branch
    branch = os.environ.get('CURRENT_BRANCH') or 'master'

    # Install environment dependencies
    env_parts = args.env.split('-')

    for key, dependencies in DEPENDENCIES:
        if key not in env_parts:
            continue

        for dep in dependencies:
            dep = dep.replace('{BRANCH}', branch)

            # Install dependency
            print('Installing dependency: %r' % (dep,))
            process = Popen(['pip', 'install', '--upgrade', dep])
            process.wait()



from .history import MergeHistoryDuplicatesTask, ScanHistoryDuplicatesTask
from .profile import CreateBackupTask


__all__ = [
    'MergeHistoryDuplicatesTask',
    'ScanHistoryDuplicatesTask',
    'CreateBackupTask'
]
